@@ -47,6 +47,7 @@ class Window(QtWidgets.QMainWindow):
     self.last_process_events = time()  # to update during heavy loads
     self.rebuilding_plots = False  # used by rebuild_plots
     self.max_hidden_history = args.max_hidden_history
+    self.selected_first_exp = False  # select first experiment to load meta, for discoverability
 
     # persistent settings
     self.settings = QtCore.QSettings('OverBoard', 'OverBoard')
@@ -415,6 +416,11 @@ class Window(QtWidgets.QMainWindow):
     table.setSortingEnabled(True)
     table.sortItems(*prev_sort)
 
+    # select first visible experiment, for discoverability
+    if exp.is_visible() and not self.selected_first_exp:
+      self.selected_first_exp = True
+      self.select_experiment(exp)
+
     self.process_events_if_needed()
 
   def on_exp_header_ready(self, exp):
@@ -552,7 +558,7 @@ class Window(QtWidgets.QMainWindow):
       self.redraw_icon(old_exp, old_icon)
       self.plots.add(old_exp)  # update its view, in case it's visible
 
-    if exp and exp.visible:  # don't select if invisible
+    if exp and exp.is_visible():  # don't select if invisible
       icon = self.table.cellWidget(exp.table_row.row(), 0)
 
       exp.is_selected = True
@@ -639,7 +645,7 @@ class Window(QtWidgets.QMainWindow):
         return True
 
       # hide or show depending on context
-      was_hidden = (exp.is_filtered or not exp.visible)
+      was_hidden = not exp.is_visible()
       exp.is_filtered = hide  # will be checked by Plots.add
 
       self.table.setRowHidden(exp.table_row.row(), hide)
@@ -707,12 +713,13 @@ class Window(QtWidgets.QMainWindow):
     self.settings.setValue('filter_edit', self.filter_edit.text())
 
     # save unchecked metric subset, up to 50 entries
-    checked_subset = set(self.metrics_subset_dropdown.get_checked_list())
-    unchecked_subset = {m: None for m in self.settings.value('metrics_subset_dropdown') if m not in checked_subset}  # previously hidden but now checked again
-    unchecked_subset.update({m: None for m in self.metrics_subset_dropdown.get_checked_list(unchecked=True)})  # merge with newly hidden
-    if len(unchecked_subset) > 50:  # keep N last
-      unchecked_subset = list(unchecked_subset)[-50:]
-    self.settings.setValue('metrics_subset_dropdown', list(unchecked_subset))
+    checked = set(self.metrics_subset_dropdown.get_checked_list())
+    prev_unchecked = self.settings.value('metrics_subset_dropdown', [], type=list)  # previously hidden
+    unchecked = {m: None for m in prev_unchecked if m not in checked}  # previously hidden but now checked again
+    unchecked.update({m: None for m in self.metrics_subset_dropdown.get_checked_list(unchecked=True)})  # merge with newly hidden
+    if len(unchecked) > 50:  # keep N last
+      unchecked = list(unchecked)[-50:]
+    self.settings.setValue('metrics_subset_dropdown', list(unchecked))
 
     # save auto-complete model for filter, up to 50 entries
     m = self.filter_edit.completer().model()
